/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.field.type;

import com.vividsolutions.jts.geom.Geometry;
import java.util.logging.Logger;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.SplitGeometryHandler;
import nl.cloudfarming.client.model.EntityCache;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 * Split handler for {@link TreatmentZone}
 * @author johan
 */
public class TreatmentZoneSplitHandler extends SplitGeometryHandler {
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.field.type");
    private final TreatmentZone sourceTreatmentZone;

    public TreatmentZoneSplitHandler(TreatmentZone treatmentZone) {
        this.sourceTreatmentZone = treatmentZone;
    }

    @Override
    public Geometry getSource() {
        return sourceTreatmentZone.getGeometry();
    }

    @Override
    public boolean handle(Geometry[] geometries, Node sourceNode) {
        ActivityField activityField = sourceTreatmentZone.getParent();
        
        if (activityField == null) {
            LOG.warning("split requested on orphan treatmentzone");
            return false;
        }

        for (int i = 0; i < geometries.length; i++) {
            // create new tzn based on original tzn and new geometry,
            TreatmentZone newTreatmentZone = new TreatmentZone(sourceTreatmentZone);
            newTreatmentZone.setGeometry(geometries[i]);
            newTreatmentZone.setName(sourceTreatmentZone.getName() + "-part-" + i);
            
            // add to same ActivityField as original:
            activityField.addTreatmentZone(newTreatmentZone);
            
            addToMap(new TreatmentZoneNode(newTreatmentZone));
        }
        removeFromMap(sourceNode);
        // TZN has no validity period like cropfield does, delete it:
        activityField.removeTreatmentZone(sourceTreatmentZone);
        EntityCache.getInstance().remove(sourceTreatmentZone);
        
        return true;
    }
        
}
